#!/bin/bash

agent_bin_folder=$(pwd)
pam_folder=$(pwd)/pam

echo "MODIFY_PAM: pam_folder:" $pam_folder

if [ ! -d ${pam_folder} ]; then
    echo "MODIFY_PAM: Error: run script from agent bin folder" 1>&2
    exit 1
fi

check_file () {
    diff /etc/pam.d/$1 ${pam_folder}/pam.d/$1$2  -y --suppress-common-lines
    if [ $? -ne 0 ]; then
        check_file_failed=1
        if [ -z $3 ]; then
            echo "MODIFY_PAM: Error: $1 files are not the same" 1>&2
            exit 1
        fi
    fi
}

modify_agent_path () {
    echo "MODIFY_PAM: replacing agent_bin_folder to" ${agent_bin_folder} "in" ${pam_folder}/pam.d/$1.modified 1>&2
    sed -e "s|{AGENT_BIN_DIR}|${agent_bin_folder}|g" ${pam_folder}/pam.d/$1.modified > ${pam_folder}/pam.d/$1.tmp
    mv ${pam_folder}/pam.d/$1.tmp ${pam_folder}/pam.d/$1.modified
}

overwrite_file () {
   echo "MODIFY_PAM: overwriting" /etc/pam.d/$1 1>&2
    cp -f ${pam_folder}/pam.d/$1.modified /etc/pam.d/$1
    chown root /etc/pam.d/$1
}

if [ "$(id -u)" != "0" ]; then
   echo "MODIFY_PAM: This script must be run as root" 1>&2
   exit 1
fi

modify_agent_path "sshd"
modify_agent_path "login"
modify_agent_path "common-auth"

check_file_failed=0

check_file "sshd" ".modified" 1
check_file "login" ".modified" 1
check_file "common-auth" ".modified" 1

if [ $check_file_failed -eq 0 ]; then
    echo "MODIFY_PAM: Environment already set" 1>&2
    exit 0
fi

echo 'MODIFY_PAM: Modifying PAM configuration files to audit login events'

check_file "sshd"
check_file "common-auth"
check_file "login"

overwrite_file "sshd"
overwrite_file "common-auth"
overwrite_file "login"

check_file "sshd" ".modified"
check_file "common-auth" ".modified"
check_file "login" ".modified"

echo 'MODIFY_PAM: Modifying PAM configuration files finished successfully'
exit 0